@@ -3,7 +3,6 @@ Prepare eo3 metadata for Sentinel-2 Level 1C data produced by Sinergise or ESA.
 
 Takes ESA zipped datasets or Sinergise dataset directories
 """
-import dataclasses
 import fnmatch
 import json
 import logging
@@ -20,14 +19,15 @@ from typing import Dict, Iterable, List, Mapping, Optional, Tuple, Union
 
 import click
 from attr import define
+from defusedxml import minidom
+
 from datacube.config import LocalConfig
 from datacube.index import index_connect
 from datacube.model import Dataset
 from datacube.ui.click import config_option, environment_option
 from datacube.utils.uris import normalise_path
-from defusedxml import minidom
-
 from eodatasets3 import DatasetDoc, DatasetPrepare, names, serialise
+from eodatasets3.prepare.s2_common import RegionLookup, FolderInfo
 from eodatasets3.properties import Eo3Interface
 from eodatasets3.ui import PathPath
 from eodatasets3.utils import pass_config
@@ -147,9 +147,14 @@ def process_datastrip_metadata(contents: str) -> Dict:
     """
     root = minidom.parseString(contents)
 
-    resolution = min(
-        int(i.firstChild.data) for i in root.getElementsByTagName("RESOLUTION")
-    )
+    resolution_tags = root.getElementsByTagName("RESOLUTION")
+    if resolution_tags:
+        resolution = min(int(i.firstChild.data) for i in resolution_tags)
+    elif root.getElementsByTagName("SPACECRAFT_NAME")[0].firstChild.data.startswith("Sentinel-2"):
+        resolution = 10.0
+    else:
+        raise ValueError("No resolution in datastrip metadata and unknown craft")
+
     return {
         "sentinel:reception_station": _value(root, "RECEPTION_STATION"),
         "sentinel:processing_center": _value(root, "PROCESSING_CENTER"),
@@ -424,41 +429,6 @@ def _rglob_with_self(path: Path, pattern: str) -> Iterable[Path]:
     yield from path.rglob(pattern)
 
 
-@dataclasses.dataclass
-class FolderInfo:
-    """
-    Information extracted from a standard S2 folder layout.
-    """
-
-    year: int
-    month: int
-    region_code: Optional[str]
-
-    # Compiled regexp for extracting year, month and region
-    # Standard layout is of the form: 'L1C/{yyyy}/{yyyy}-{mm}/{area}/S2*_{region}_{timestamp}(.zip)'
-    STANDARD_SUBFOLDER_LAYOUT = re.compile(
-        r"(\d{4})/(\d{4})-(\d{2})/[\dNESW]+-[\dNESW]+/"
-        r"S2[AB](?:_OPER_PRD)?_MSIL1C(?:_PDMC)?(?:_[a-zA-Z0-9]+){3}(?:_T([A-Z\d]+))?_[\dT]+(\.zip|/tileInfo\.json)?$"
-    )
-
-    @classmethod
-    def for_path(cls, path: Path) -> Optional["FolderInfo"]:
-        """
-        Can we extract information from the given path?
-
-        Returns None if we can't.
-        """
-        m = cls.STANDARD_SUBFOLDER_LAYOUT.search(path.as_posix())
-        if not m:
-            return None
-
-        year, year2, month, region_code, extension = m.groups()
-        if year != year2:
-            raise ValueError(f"Year mismatch in {path}")
-
-        return FolderInfo(int(year), int(month, 10), region_code)
-
-
 class YearMonth(click.ParamType):
     """A YYYY-MM string converted to an integer tuple"""
 
@@ -734,6 +704,9 @@ def main(
             )
 
     def find_jobs() -> Iterable[Job]:
+
+        region_lookup = RegionLookup()
+
         nonlocal input_relative_to, embed_location
         for input_path in datasets:
 
@@ -751,11 +724,23 @@ def main(
                 if included_regions or before_month or after_month:
                     if info is None:
                         raise ValueError(
-                            f"Cannot filter from non-standard folder layout: {found_dataset.path}"
+                            f"Cannot filter from non-standard folder layout: {found_dataset.path} "
+                            f" expected of form L1C/yyyy/yyyy-mm/area/S2_.."
                         )
 
                     if included_regions:
-                        if info.region_code not in included_regions:
+                        # If it's an older dataset without a region, try to map its area to a known region.
+                        if info.region_code is None:
+                            for region in region_lookup.get(info.area):
+                                if region in included_regions:
+                                    _LOG.debug(f'Area {info.area!r} mapped to (included) region {region!r}')
+                                    break
+                            else:
+                                _LOG.debug(
+                                    f"Skipping because area {info.area!r} doesn't map to an included region"
+                                )
+                                continue
+                        elif info.region_code not in included_regions:
                             _LOG.debug(
                                 f"Skipping because region {info.region_code!r} is not in region list"
                             )
